@@ -32,10 +32,12 @@ class SendGrid(object):
                 "del": "/api/newsletter/lists/email/delete.json"},
             "recipients": {  # recipients for a newsletter
                 "add": "/api/newsletter/recipients/add.json",
-                "get": "/api/newsletter/recipients/get.json"},
+                "get": "/api/newsletter/recipients/get.json",
+                "del": "/api/newsletter/delete.json"},
             "schedule": {  # schedule to send
                 "add": "/api/newsletter/schedule/add.json",
-                "get": "/api/newsletter/schedule/get.json"},
+                "get": "/api/newsletter/schedule/get.json",
+                "del": "/api/newsletter/schedule/delete.json"},
             "identity": {  # identities for newsletter
                 "add": "/api/newsletter/identity/add.json",
                 "list": "/api/newsletter/identity/list.json",
@@ -161,6 +163,12 @@ class SendGrid(object):
                 times = 0
         return api_call
 
+    def get_recipients(self, newsletter_name):
+        return self.call("recipients", "get", dict(name=newsletter_name))
+
+    def del_recipients(self, newsletter_name, list):
+        return self.call("recipients", "del", dict(newsletter_name, list))
+
     def add_schedule(self, newsletter_name, at=None, after=None):
         if at:
             d = dict(name=newsletter_name, at=at.isoformat())
@@ -170,6 +178,12 @@ class SendGrid(object):
             d = dict(name=newsletter_name)
         return self.call('schedule', 'add', d)
 
+    def get_schedule(self, name):
+        return self.call('schedule', 'get', dict(name=name))
+
+    def del_schedule(self, name):
+        return self.call('schedule', 'del', dict(name=name))
+
     def add_subuser(self, **fields):
         return self.call('subuser', 'add', dict(**fields))
 
